<?php include('db_connect.php'); ?>
<!DOCTYPE html>
<html>

<head>
  <title>Absent Students List</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
  <style>
    .filter-wrapper {
      margin-top: 20px;
      margin-left: 20px;
    }

    .filter-wrapper .checkBox {
      margin-right: 10px;
    }
  </style>
</head>

<body>
  <div class="container-fluid">
    <div class="row mt-3">
      <div class="col-lg-12">
        <div class="card">
          <div class="card-header">
            <div class="filter-wrapper">
              <form id="filterForm">
                <label for="absentDate"><b>Please select Date to see the list of Absent Students:</b></label>
                <input type="date" id="absentDate" name="date">
                <button type="submit">Filter</button>
              </form>
              <button type="button" id="exportPdfBtn" class="btn btn-sm btn-primary">Export to PDF</button>
            </div>
          </div>
          <div class="card-body table-responsive">
            <table id="myTable" class="table table-bordered table-sm table-striped nowrap compact">
              <thead>
                <tr>
                  <th class="text-center">#</th>
                  <th class="text-center">Program</th>
                  <th class="text-center">Year Level</th>
                  <th class="text-center">Section</th>
                  <th class="text-center">Last Name</th>
                  <th class="text-center">First Name</th>
                  <th class="text-center">Email Address</th>
                  <th class="text-center">Gender</th>
                  <th class="text-center">Age</th>
                  <th class="text-center">Student ID</th>
                </tr>
              </thead>
              <tbody>
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  </div>

  <div class="modal fade" id="eventModal" tabindex="-1">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title">Select Event for PDF</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
        </div>
        <div class="modal-body">
          <select id="eventSelect" class="form-control">
          </select>
        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
          <button type="button" class="btn btn-primary" id="confirmEventBtn">Confirm</button>
        </div>
      </div>
    </div>
  </div>

  <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf/2.5.1/jspdf.umd.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf-autotable/3.5.15/jspdf.plugin.autotable.min.js"></script>

  <script>
    $(document).ready(function() {
      const today = new Date().toISOString().split('T')[0];
      $('#absentDate').val(today);

      function fetchEvents() {
        $.ajax({
          url: 'fetch_events.php',
          method: 'GET',
          success: function(data) {
            $('#eventSelect').html(data);
          }
        });
      }

      function loadAbsentStudents(date = today) {
        $.ajax({
          url: 'fetch_absent.php',
          method: 'GET',
          data: {
            date: date
          },
          success: function(data) {
            $('#myTable tbody').html(data);
          }
        });
      }

      loadAbsentStudents();

      $('#filterForm').submit(function(e) {
        e.preventDefault();
        var date = $('#absentDate').val();
        loadAbsentStudents(date);
      });

      $('#exportPdfBtn').click(function() {
        fetchEvents();
        var eventModal = new bootstrap.Modal(document.getElementById('eventModal'));
        eventModal.show();
      });

      $('#confirmEventBtn').click(function() {
        const {
          jsPDF
        } = window.jspdf;
        const doc = new jsPDF();

        const selectedEvent = $('#eventSelect').val().split('|');
        const eventName = selectedEvent[0];
        const eventDate = selectedEvent[1];
        const eventLocation = selectedEvent[2];

        const table = document.getElementById('myTable');
        const selectedDate = $('#absentDate').val();

        doc.setFontSize(18);
        doc.text('Absent Students List', 14, 22);
        doc.setFontSize(12);
        doc.text(`Event: ${eventName}`, 14, 32);
        doc.text(`Date: ${selectedDate}`, 14, 39);
        doc.text(`Location: ${eventLocation}`, 14, 46);

        doc.autoTable({
          html: '#myTable',
          startY: 55,
          styles: {
            fontSize: 8,
            cellPadding: 2,
            overflow: 'linebreak'
          },
          columnStyles: {
            0: {
              cellWidth: 'auto'
            },
            1: {
              cellWidth: 'auto'
            },
            2: {
              cellWidth: 'auto'
            },
            3: {
              cellWidth: 'auto'
            },
            4: {
              cellWidth: 'auto'
            },
            5: {
              cellWidth: 'auto'
            },
            6: {
              cellWidth: 'auto'
            },
            7: {
              cellWidth: 'auto'
            },
            8: {
              cellWidth: 'auto'
            },
            9: {
              cellWidth: 'auto'
            }
          },
          margin: {
            left: 10,
            right: 10
          }
        });
        doc.save(`Absent_Students_${eventName}_${selectedDate}.pdf`);

        var eventModal = bootstrap.Modal.getInstance(document.getElementById('eventModal'));
        eventModal.hide();
      });

    });
  </script>
</body>

</html>