<?php include('db_connect.php'); ?>
<!DOCTYPE html>
<html>

<head>
  <title>Attendance</title>
  <style>
    .filter-wrapper {
      margin-top: 20px;
      margin-left: 20px;
    }

    .filter-wrapper .checkBox {
      margin-right: 10px;
    }
  </style>
</head>

<body>
  <div class="container-fluid">
    <div class="row mt-3">
      <div class="col-lg-12">
        <div class="card">
          <div class="card-header">
            <b>List of Attendance</b>
            <div class="filter-wrapper">
              <form id="filterForm">
                <div class="row">
                  <div class="col-md-3">
                    <label for="program"><b>Program:</b></label>
                    <select id="program" name="program" class="form-control">
                      <option value="">All Programs</option>
                      <?php
                      $program_query = "SELECT DISTINCT program FROM students WHERE status = 1 AND archive_status = 0 ORDER BY program";
                      $programs = $conn->query($program_query);
                      while ($prog = $programs->fetch_assoc()) {
                        echo "<option value='" . htmlspecialchars($prog['program']) . "'>" . ucwords($prog['program']) . "</option>";
                      }
                      ?>
                    </select>
                  </div>
                  <div class="col-md-3">
                    <label for="year_level"><b>Year Level:</b></label>
                    <select id="year_level" name="year_level" class="form-control">
                      <option value="">All Years</option>
                      <?php
                      $year_query = "SELECT DISTINCT year_level FROM students WHERE status = 1 AND archive_status = 0 ORDER BY year_level";
                      $years = $conn->query($year_query);
                      while ($year = $years->fetch_assoc()) {
                        echo "<option value='" . htmlspecialchars($year['year_level']) . "'>" . ucwords($year['year_level']) . "</option>";
                      }
                      ?>
                    </select>
                  </div>
                  <div class="col-md-3">
                    <label for="section"><b>Section:</b></label>
                    <select id="section" name="section" class="form-control">
                      <option value="">All Sections</option>
                      <?php
                      $section_query = "SELECT DISTINCT section FROM students WHERE status = 1 AND archive_status = 0 ORDER BY section";
                      $sections = $conn->query($section_query);
                      while ($sect = $sections->fetch_assoc()) {
                        echo "<option value='" . htmlspecialchars($sect['section']) . "'>" . ucwords($sect['section']) . "</option>";
                      }
                      ?>
                    </select>
                  </div>
                  <div class="col-md-3">
                    <label for="date"><b>Date:</b></label>
                    <input type="date" id="date" name="date" class="form-control">
                  </div>
                </div>
                <div class="row mt-3">
                  <div class="col">
                    <button type="submit" class="btn btn-primary">Filter</button>
                    <button type="button" id="resetFilterBtn" class="btn btn-secondary">Reset Filters</button>
                    <button type="button" id="exportPdfBtn" class="btn btn-primary">Export to PDF</button>
                  </div>
                </div>
              </form>
            </div>
          </div>
          <div class="card-body table-responsive">
            <table id="myTable" class="table table-bordered table-sm table-striped nowrap compact">
              <thead>
                <tr>
                  <th class="text-center">#</th>
                  <th class="text-center">Program</th>
                  <th class="text-center">Year Level</th>
                  <th class="text-center">Section</th>
                  <th class="text-center">Last Name</th>
                  <th class="text-center">First Name</th>
                  <th class="text-center">Student ID</th>
                  <th class="text-center">Time in</th>
                  <th class="text-center">Time out</th>
                </tr>
              </thead>
              <tbody>
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  </div>

  <div class="modal fade" id="eventModal" tabindex="-1">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title">Select Event for PDF</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
        </div>
        <div class="modal-body">
          <select id="eventSelect" class="form-control">
          </select>
        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
          <button type="button" class="btn btn-primary" id="confirmEventBtn">Confirm</button>
        </div>
      </div>
    </div>
  </div>

  <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf/2.5.1/jspdf.umd.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf-autotable/3.5.15/jspdf.plugin.autotable.min.js"></script>

  <script>
    $(document).ready(function() {
      const today = new Date().toISOString().split('T')[0];
      $('#date').val(today);
      let selectedEventDetails = null;

      function loadStudents(filters = {}) {
        filters.date = filters.date || today;
        filters.program = filters.program || '';
        filters.year_level = filters.year_level || '';
        filters.section = filters.section || '';

        $.ajax({
          url: 'fetch_attendance.php',
          method: 'GET',
          data: filters,
          success: function(data) {
            $('#myTable tbody').html(data);
          }
        });
      }

      loadStudents();

      $('#filterForm').submit(function(e) {
        e.preventDefault();
        const filters = {
          date: $('#date').val(),
          program: $('#program').val(),
          year_level: $('#year_level').val(),
          section: $('#section').val()
        };
        loadStudents(filters);
      });

      $('#resetFilterBtn').click(function() {
        $('#program').val('');
        $('#year_level').val('');
        $('#section').val('');
        $('#date').val(today);
        loadStudents();
      });

      function fetchEvents() {
        $.ajax({
          url: 'fetch_events.php',
          method: 'GET',
          success: function(data) {
            $('#eventSelect').html(data);
          }
        });
      }

      $('#exportPdfBtn').click(function() {
        fetchEvents();
        var eventModal = new bootstrap.Modal(document.getElementById('eventModal'));
        eventModal.show();
      });

      $('#confirmEventBtn').click(function() {
        try {
          const selectedEvent = $('#eventSelect').val().split('|');
          if (!selectedEvent || selectedEvent.length < 3) {
            alert('Please select an event first');
            return;
          }

          const eventName = selectedEvent[0];
          const eventDate = selectedEvent[1];
          const eventLocation = selectedEvent[2];

          const {
            jsPDF
          } = window.jspdf;
          const doc = new jsPDF('landscape');

          doc.addImage('./assets/img/sjcb-logo.png', 'PNG', 14, 10, 20, 20);

          doc.setProperties({
            title: `Attendance List - ${eventName}`,
            subject: `Event Attendance for ${eventDate}`,
            creator: 'Attendance System'
          });

          doc.setFontSize(20);
          doc.setFont('helvetica', 'bold');
          doc.text('ATTENDANCE RECORD', doc.internal.pageSize.width / 2, 25, {
            align: 'center'
          });

          doc.setFontSize(12);
          doc.setFont('helvetica', 'normal');

          doc.setFillColor(240, 240, 240);
          doc.rect(14, 35, 270, 25, 'F');

          doc.setFont('helvetica', 'bold');
          doc.text('Event:', 20, 45);
          doc.text('Date:', 20, 52);
          doc.text('Location:', 150, 45);

          doc.setFont('helvetica', 'normal');
          doc.text(eventName, 45, 45);
          doc.text(eventDate, 45, 52);
          doc.text(eventLocation, 175, 45);

          doc.autoTable({
            html: '#myTable',
            startY: 70,
            styles: {
              fontSize: 9,
              cellPadding: 3,
              lineColor: [0, 0, 0],
              lineWidth: 0.1
            },
            headStyles: {
              fillColor: [51, 122, 183],
              textColor: [255, 255, 255],
              fontSize: 10,
              fontStyle: 'bold',
              halign: 'center'
            },
            bodyStyles: {
              halign: 'center'
            },
            alternateRowStyles: {
              fillColor: [245, 245, 245]
            },
            columnStyles: {
              0: {
                cellWidth: 20
              }, // #
              1: {
                cellWidth: 35
              }, // Program
              2: {
                cellWidth: 30
              }, // Year Level
              3: {
                cellWidth: 30
              }, // Section
              4: {
                cellWidth: 35
              }, // Last Name
              5: {
                cellWidth: 35
              }, // First Name
              6: {
                cellWidth: 35
              }, // Student ID
              7: {
                cellWidth: 25
              }, // Time in
              8: {
                cellWidth: 25
              } // Time out
            },
            margin: {
              top: 70,
              left: 14,
              right: 14,
              bottom: 20
            },
            didDrawPage: function(data) {
              doc.setFontSize(10);
              doc.text(
                `Page ${data.pageNumber} of ${doc.getNumberOfPages()}`,
                doc.internal.pageSize.width - 20,
                doc.internal.pageSize.height - 10, {
                  align: 'right'
                }
              );

              doc.setFontSize(8);
              doc.text(
                'Generated by Institutional Mass Attendance Monitoring System',
                doc.internal.pageSize.width / 2,
                doc.internal.pageSize.height - 10, {
                  align: 'center'
                }
              );
            }
          });

          const filename = `Attendance_${eventName.replace(/\s+/g, '_')}_${eventDate.replace(/\//g, '-')}.pdf`;
          doc.save(filename);

          const eventModal = bootstrap.Modal.getInstance(document.getElementById('eventModal'));
          eventModal.hide();
        } catch (error) {
          console.error('Error generating PDF:', error);
          alert('There was an error generating the PDF. Please try again.');
        }
      });
    });
  </script>
</body>

</html>