<?php
include('db_connect.php');

$programs = $conn->query("SELECT DISTINCT program FROM students WHERE archive_status = 0");
$yearLevels = $conn->query("SELECT DISTINCT year_level FROM students WHERE archive_status = 0");
$sections = $conn->query("SELECT DISTINCT section FROM students WHERE archive_status = 0");

$sql = "SELECT id, firstname, lastname, gender, email, status, age, student_id, program, year_level, section FROM students WHERE archive_status = 0";
$result = $conn->query($sql);
?>


<!DOCTYPE html>
<html>

<head>
	<title>Students List</title>
	<style>
		.qr-container {
			margin-top: 10px;
			display: none;
			text-align: center;
		}

		.qr-container img {
			margin-top: 10px;
		}

		.student-details {
			text-align: center;
			font-family: Arial, sans-serif;
		}

		.student-details .row {
			margin-bottom: 15px;
		}

		.student-details .row b {
			font-size: 1.2em;
		}

		.student-details .qr-code-container {
			margin-top: 20px;
		}

		.logo {
			margin-bottom: 20px;
		}
	</style>
	<script src="https://cdn.jsdelivr.net/npm/qrcode/build/qrcode.min.js"></script>
	<script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.10.1/jszip.min.js"></script>
</head>

<body>
	<div class="container-fluid">
		<div class="row mt-3">
			<div class="col-lg-12">
				<div class="card">
					<div class="card-header">
						<b>List of Students</b>
					</div>

					<div class="card-body table-responsive">
						<div id="filters" class="mb-3">
							<select id="programFilter" class="filter-select" data-column="2">
								<option value="">All Programs</option>
								<?php while ($row = $programs->fetch_assoc()): ?>
									<option value="<?php echo htmlspecialchars($row['program']); ?>">
										<?php echo htmlspecialchars($row['program']); ?>
									</option>
								<?php endwhile; ?>
							</select>

							<select id="yearLevelFilter" class="filter-select" data-column="3">
								<option value="">All Year Levels</option>
								<?php while ($row = $yearLevels->fetch_assoc()): ?>
									<option value="<?php echo htmlspecialchars($row['year_level']); ?>">
										<?php echo htmlspecialchars($row['year_level']); ?>
									</option>
								<?php endwhile; ?>
							</select>

							<select id="sectionFilter" class="filter-select" data-column="4">
								<option value="">All Sections</option>
								<?php while ($row = $sections->fetch_assoc()): ?>
									<option value="<?php echo htmlspecialchars($row['section']); ?>">
										<?php echo htmlspecialchars($row['section']); ?>
									</option>
								<?php endwhile; ?>
							</select>

							<button id="resetFilter" class="btn btn-secondary ml-2">Reset Filters</button>
						</div>
						<div id="batch-qr-controls" class="mb-3">
							<button id="generate-batch-qr" class="btn btn-success">Generate Batch QR Codes</button>
							<label class="ml-2">
								<input type="checkbox" id="select-all-students"> Select All
							</label>
						</div>
						<table id="myTable" class="table table-bordered table-sm table-striped nowrap compact">
							<thead>
								<tr>
									<th class="text-center">
										<input type="checkbox" id="batch-select-header">
									</th>
									<th class="text-center">#</th>
									<th class="text-center">Program</th>
									<th class="text-center">Year Level</th>
									<th class="text-center">Section</th>
									<th class="text-center">Student ID</th>
									<th class="text-center">Last Name</th>
									<th class="text-center">First Name</th>
									<th class="text-center">Email Address</th>
									<th class="text-center">Gender</th>
									<th class="text-center">Age</th>
									<th class="text-center">Action</th>
								</tr>
							</thead>
							<tbody>
								<?php
								$count = 1;
								if ($result->num_rows > 0) {
									while ($row = $result->fetch_assoc()) {
										$status = $row['status'] == 1 ? 'Active' : 'Inactive';
								?>
										<tr>
											<td class="text-center">
												<input type="checkbox" class="student-checkbox"
													data-student-id="<?php echo htmlspecialchars($row['student_id'] ?? ''); ?>"
													data-student-lastname="<?php echo htmlspecialchars($row['lastname']); ?>"
													data-student-firstname="<?php echo htmlspecialchars($row['firstname']); ?>"
													data-student-program="<?php echo htmlspecialchars($row['program']); ?>"
													data-student-yearlevel="<?php echo htmlspecialchars($row['year_level']); ?>"
													data-student-section="<?php echo htmlspecialchars($row['section']); ?>">
											</td>
											<td class="text-center"><?php echo $count; ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['program']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['year_level']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['section']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['student_id'] ?? 'N/A'); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['lastname']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['firstname']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['email']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['gender']); ?></td>
											<td class="text-center"><?php echo htmlspecialchars($row['age']); ?></td>
											<td class="text-center">
												<button class="btn btn-sm btn-primary edit_student" type="button" data-id="<?php echo $row['id'] ?>">
													<span><i class="fa-solid fa-image"></i></span>
												</button>

												<button class="btn btn-sm btn-primary generate-qr-btn"
													data-student-id="<?php echo htmlspecialchars($row['student_id'] ?? ''); ?>"
													data-student-lastname="<?php echo htmlspecialchars($row['lastname']); ?>"
													data-student-firstname="<?php echo htmlspecialchars($row['firstname']); ?>"
													data-student-program="<?php echo htmlspecialchars($row['program']); ?>"
													data-student-yearlevel="<?php echo htmlspecialchars($row['year_level']); ?>" data-student-section="<?php echo htmlspecialchars($row['section']); ?>">
													<i class="fa-solid fa-qrcode"></i>

												</button>
												<button class="btn ml-2 btn-sm btn-warning archive_student" type="button"
													data-id="<?php echo $row['id'] ?>"><i class="fa-solid fa-box-archive"></i></button>
											</td>
										</tr>
								<?php
										$count++;
									}
								} else {
									echo "<tr><td colspan='12' class='text-center'>No students found</td></tr>";
								}
								?>
							</tbody>
						</table>
					</div>
				</div>
			</div>
		</div>
	</div>

	<div id="qr-container" class="qr-container"></div>

	<script>
		$(".edit_student").click(function() {
			uni_modal(
				"Manage Profile Picture",
				"mng_img.php?id=" + $(this).attr("data-id"),
				"mid-large"
			);
		});

		$(".archive_student").click(function() {
			_conf("Are you sure to archive this student?", "archive_student", [$(this).attr("data-id")]);
		});

		function archive_student($id) {
			start_load();
			$.ajax({
				url: "ajax.php?action=archive_student",
				method: "POST",
				data: {
					id: $id
				},
				success: function(resp) {
					if (resp == 1) {
						alert_toast("student successfully archived", "success");
						setTimeout(function() {
							location.reload();
						}, 1500);
					}
				},
			});
		}

		function generateQRCode(studentId, lastname, firstname, program, yearLevel, section) {
			QRCode.toCanvas(document.createElement('canvas'), studentId, function(error, canvas) {
				if (error) {
					console.error('Error generating QR code:', error);
					return;
				}
				const compositeCanvas = document.createElement('canvas');
				const ctx = compositeCanvas.getContext('2d');
				const padding = 20;
				const logoHeight = 100;
				const qrSize = 200;
				const textHeight = 80;
				compositeCanvas.width = 350;
				compositeCanvas.height = logoHeight + textHeight + qrSize + (padding * 3);
				ctx.fillStyle = '#ffffff';
				ctx.fillRect(0, 0, compositeCanvas.width, compositeCanvas.height);
				const logo = new Image();
				logo.onload = function() {
					const logoX = (compositeCanvas.width - logoHeight) / 2;
					ctx.drawImage(logo, logoX, padding, logoHeight, logoHeight);
					ctx.fillStyle = '#000000';
					ctx.textAlign = 'center';
					const centerX = compositeCanvas.width / 2;
					let currentY = logoHeight + (padding * 2);
					ctx.font = 'bold 16px Arial';
					ctx.fillText(lastname + ' ' + firstname, centerX, currentY);
					currentY += 25;
					ctx.font = '14px Arial';
					ctx.fillText('Student ID: ' + studentId, centerX, currentY);
					currentY += 20;
					ctx.fillText(program + ' - Year ' + yearLevel + ' - Section ' + section, centerX, currentY);
					const qrX = (compositeCanvas.width - qrSize) / 2;
					const qrY = currentY + padding;
					ctx.drawImage(canvas, qrX, qrY, qrSize, qrSize);
					const finalImgUrl = compositeCanvas.toDataURL('image/png');
					const downloadLink = document.createElement('a');
					downloadLink.href = finalImgUrl;
					downloadLink.download = 'student_qrcode_' + studentId + '.png';
					downloadLink.click();
				};
				logo.src = 'assets/img/sjcb-logo.png';
			});
		}
		$(document).ready(function() {
			$('#myTable').on('click', '.generate-qr-btn', function() {
				const studentId = $(this).data('student-id');
				const lastname = $(this).data('student-lastname');
				const firstname = $(this).data('student-firstname');
				const program = $(this).data('student-program');
				const yearLevel = $(this).data('student-yearlevel');
				const section = $(this).data('student-section');
				generateQRCode(studentId, lastname, firstname, program, yearLevel, section);
			});
		});

		$(document).ready(function() {
			$('#select-all-students, #batch-select-header').change(function() {
				const isChecked = $(this).prop('checked');
				$('.student-checkbox').prop('checked', isChecked);
			});

			$('#generate-batch-qr').click(function() {
				const selectedStudents = $('.student-checkbox:checked').map(function() {
					return {
						studentId: $(this).data('student-id'),
						lastname: $(this).data('student-lastname'),
						firstname: $(this).data('student-firstname'),
						program: $(this).data('student-program'),
						yearLevel: $(this).data('student-yearlevel'),
						section: $(this).data('student-section')
					};
				}).get();

				if (selectedStudents.length === 0) {
					alert("Please select at least one student to generate QR codes.");
					return;
				}

				const zip = new JSZip();
				const promises = [];

				selectedStudents.forEach(student => {
					promises.push(new Promise((resolve) => {
						QRCode.toCanvas(document.createElement('canvas'), student.studentId, function(error, canvas) {
							if (error) {
								console.error('Error generating QR code:', error);
								resolve(null);
								return;
							}
							const compositeCanvas = document.createElement('canvas');
							const ctx = compositeCanvas.getContext('2d');
							const padding = 20;
							const logoHeight = 100;
							const qrSize = 200;
							const textHeight = 80;
							compositeCanvas.width = 350;
							compositeCanvas.height = logoHeight + textHeight + qrSize + (padding * 3);
							ctx.fillStyle = '#ffffff';
							ctx.fillRect(0, 0, compositeCanvas.width, compositeCanvas.height);
							const logo = new Image();
							logo.onload = function() {
								const logoX = (compositeCanvas.width - logoHeight) / 2;
								ctx.drawImage(logo, logoX, padding, logoHeight, logoHeight);
								ctx.fillStyle = '#000000';
								ctx.textAlign = 'center';
								const centerX = compositeCanvas.width / 2;
								let currentY = logoHeight + (padding * 2);
								ctx.font = 'bold 16px Arial';
								ctx.fillText(student.lastname + ' ' + student.firstname, centerX, currentY);
								currentY += 25;
								ctx.font = '14px Arial';
								ctx.fillText('Student ID: ' + student.studentId, centerX, currentY);
								currentY += 20;
								ctx.fillText(student.program + ' - Year ' + student.yearLevel + ' - Section ' + student.section, centerX, currentY);
								const qrX = (compositeCanvas.width - qrSize) / 2;
								const qrY = currentY + padding;
								ctx.drawImage(canvas, qrX, qrY, qrSize, qrSize);

								compositeCanvas.toBlob(function(blob) {
									zip.file(`student_qrcode_${student.studentId}.png`, blob);
									resolve();
								});
							};
							logo.src = 'assets/img/sjcb-logo.png';
						});
					}));
				});

				Promise.all(promises).then(() => {
					zip.generateAsync({
							type: "blob"
						})
						.then(function(content) {
							const link = document.createElement('a');
							link.href = URL.createObjectURL(content);
							link.download = 'student_qrcodes_batch.zip';
							link.click();
						});
				});
			});
		});
	</script>
</body>

</html>