<?php
include 'admin/db_connect.php';

$today = date('Y-m-d');
$query = "SELECT event_name, event_time, location FROM event WHERE event_date = '$today' AND status = 'scheduled'";
$result = $conn->query($query);

$event_details = "No event today.";
if ($result && $result->num_rows > 0) {
  $event = $result->fetch_assoc();
  $event_details = "Event: " . $event['event_name'] . "<br>" .
    "Time: " . $event['event_time'] . "<br>" .
    "Location: " . $event['location'];
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Attendance</title>
  <style>
    table.table-bordered {
      border-width: 2px;
    }

    table.table-bordered th,
    table.table-bordered td {
      border: 1px solid black !important;
    }

    body {
      font-family: 'Poppins', sans-serif;
      position: relative;
      min-height: 100vh;
      display: flex;
      align-items: center;
      justify-content: center;
    }

    .background-image {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-image: url('assets/img/background-image.jpg');
      background-size: cover;
      background-position: center;
      background-repeat: no-repeat;
      z-index: -1;
    }

    .overlay {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.5);
      z-index: 1;
    }

    .d-flex {
      display: flex;
    }

    .justify-content-center {
      justify-content: center;
    }

    .align-items-center {
      align-items: center;
    }

    .mb-2 {
      margin-bottom: 20px;
    }

    .logo {
      width: 100px;
      margin-right: 15px;
    }

    .text-white {
      color: white;
    }

    .attendance-form {
      max-width: 500px;
      margin: 0 auto;
      background-color: rgba(255, 255, 255, 0.8);
      padding: 30px;
      border-radius: 10px;
      box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
    }

    .attendance-form label {
      display: block;
      margin-bottom: 10px;
      font-weight: 700;
    }

    .attendance-form input[type="text"] {
      width: 100%;
      padding: 8px;
      margin-bottom: 20px;
      border: 1px solid #ccc;
      border-radius: 4px;
      box-sizing: border-box;
    }

    .attendance-form button {
      background-color: #4CAF50;
      color: white;
      padding: 10px 20px;
      border: none;
      border-radius: 4px;
      cursor: pointer;
      transition: background-color 0.3s;
    }

    .attendance-form button:hover {
      background-color: #45a049;
    }

    .datetime-display {
      background-color: rgba(255, 255, 255, 0.8);
      padding: 10px 20px;
      border-radius: 5px;
      box-shadow: 0 0 10px rgba(0, 0, 0, 0.2);
      margin-bottom: 30px;
    }
  </style>
</head>

<body>
  <div class="container">
    <div class="d-flex justify-content-center align-items-center mb-2">
      <img src="assets/img/sjcb-logo.png" alt="School Logo" class="logo">
      <h1 class="text-center text-white">Institutional Mass Attendance Monitoring System</h1>
    </div>
    <div class="background-image">
      <div class="overlay"></div>
    </div>
    <div class="d-flex justify-content-center">
      <h3 class="datetime-display">
        <?php echo $event_details; ?>
      </h3>
    </div>
    <div class="d-flex justify-content-center">
      <h3 class="datetime-display" id="datetime">
      </h3>
    </div>
    <div class="attendance-form">
      <form id="attendanceForm">
        <label for="student_id">Enter Student ID:</label>
        <input type="text" id="student_id" name="student_id" placeholder="Student ID" required>
      </form>
    </div>
  </div>

  <script>
    $(document).ready(function() {
      if (typeof openLoginModal !== 'undefined' && openLoginModal) {
        uni_modal("Login", "popup.php");
      }

      $('#student_id').on('keyup', function(e) {
        if (this.value.length === 11) {
          recordAttendance(this.value);
          this.value = '';
        }
      });
    });

    function recordAttendance(studentId) {
      if (studentId === "") {
        showAlert("Please enter a Student ID.", "error");
        return;
      }

      $.ajax({
        url: 'admin/ajax.php?action=save_attendance',
        data: {
          student_id: studentId
        },
        method: 'POST',
        success: function(resp) {
          try {
            const response = JSON.parse(resp);
            const student = response.student;
            const imgPath = student.img ? `./admin/uploads/${student.img}` : 'assets/img/default-avatar.jpg';

            setTimeout(() => {
              Swal.fire({
                title: getAlertTitle(response.status),
                html: `
              <div class="student-profile">
                <img src="${imgPath}" alt="Student Photo" 
                     style="width: 150px; height: 150px; border-radius: 50%; margin-bottom: 15px; object-fit: cover;">
                <p class="student-name">${student.firstname} ${student.lastname}</p>
                <p class="student-id">${student.student_id}</p>
                <p class="student-program">${student.program} - ${student.year_level}${student.section}</p>
                <p class="message">${response.message}</p>
              </div>
            `,
                icon: response.status,
                timer: 5000,
                timerProgressBar: true,
                showConfirmButton: false,
                didOpen: () => {
                  const soundFile = response.status === 'success' ? 'success.mp3' : 'warning.mp3';
                  new Audio(soundFile).play();
                }
              });
            }, 500);

            $('#student_id').val('');
          } catch (e) {
            showAlert("Error processing response", "error");
          }
        },
        error: function() {
          showAlert("An error occurred while processing the request.", "error");
        }
      });
    }

    function getAlertTitle(status) {
      switch (status) {
        case 'success':
          return 'Success';
        case 'warning':
          return 'Warning';
        default:
          return 'Error';
      }
    }

    function getAlertIcon(message) {
      if (message.includes("successfully")) return "success";
      if (message.includes("already")) return "warning";
      return "error";
    }

    function playAlertSound(message) {
      const soundFile = message.includes("successfully") ? 'success.mp3' : 'warning.mp3';
      new Audio(soundFile).play();
    }

    const styles = `
  .student-profile {
    text-align: center;
    padding: 10px;
  }
  
  .student-profile img {
    box-shadow: 0 2px 5px rgba(0,0,0,0.2);
  }
  
  .student-name {
    font-size: 1.2em;
    font-weight: bold;
    margin: 10px 0 5px;
  }
  
  .student-id {
    color: #666;
    margin: 5px 0;
  }
  
  .student-program {
    color: #444;
    margin: 5px 0;
  }
  
  .message {
    margin-top: 15px;
    color: #4CAF50;
    font-weight: bold;
  }
`;

    function showAlert(message, icon) {
      let iconValue, title, audio;

      switch (icon) {
        case "success":
          iconValue = "success";
          title = "Success";
          audio = new Audio('success.mp3');
          break;
        case "warning":
          iconValue = "warning";
          title = "Warning";
          audio = new Audio('warning.mp3');
          break;
        default:
          iconValue = "error";
          title = "Error";
          audio = new Audio('warning.mp3');
      }

      Swal.fire({
        title: title,
        text: message,
        icon: iconValue,
        timer: 3000,
        showConfirmButton: false,
        didOpen: () => {
          audio.play();
        }
      });
    }

    function updateDateTime() {
      var now = new Date();
      var options = {
        weekday: 'long',
        year: 'numeric',
        month: 'long',
        day: 'numeric',
        hour: 'numeric',
        minute: 'numeric',
        second: 'numeric',
        hour12: false
      };
      document.getElementById('datetime').textContent = now.toLocaleString('en-US', options);
    }

    setInterval(updateDateTime, 1000);
    updateDateTime();
  </script>
</body>

</html>